RV.randtest: Monte-Carlo Test on the sum of eigenvalues of a co-inertia analysis (in C++ with Rcpp).
Description
performs a Monte-Carlo Test on the sum of eigenvalues of a co-inertia analysis.
Usage
RV.randtest(df1, df2, nrepet = 999, ...)
Arguments
Value
returns a list of class 'randtest'
References
Heo, M. & Gabriel, K.R. (1997) A permutation test of association between configurations by means of the RV coefficient.
Communications in Statistics - Simulation and Computation, 27, 843-856.