Learn R Programming

ade4 (version 1.7-24)

RVintra.randtest: Monte-Carlo Test on the sum of eigenvalues of a within-class co-inertia analysis (in C++ with Rcpp).

Description

performs a Monte-Carlo Test on the sum of eigenvalues of a within-class co-inertia analysis.

Usage

RVintra.randtest(df1, df2, fac, nrepet = 999, ...)

Arguments

Value

returns a list of class 'randtest'

References

Heo, M. & Gabriel, K.R. (1997) A permutation test of association between configurations by means of the RV coefficient. Communications in Statistics - Simulation and Computation, 27, 843-856.

Examples

Run this code
data(meaudret)
pca1 <- dudi.pca(meaudret$env, scan = FALSE, nf = 4)
pca2 <- dudi.pca(meaudret$spe, scal = FALSE, scan = FALSE, nf = 4)
wit1 <- wca(pca1, meaudret$design$season, scan = FALSE, nf = 2)
wit2 <- wca(pca2, meaudret$design$season, scan = FALSE, nf = 2)
coiw <- coinertia(wit1, wit2, scann = FALSE)
rv1 <- RVintra.randtest(pca1$tab, pca2$tab, meaudret$design$season, nrep=999)
rv1
plot(rv1)

Run the code above in your browser using DataLab