Learn R Programming

ade4 (version 1.7-4)

foucart: K-tables Correspondence Analysis with the same rows and the same columns

Description

K tables have the same rows and the same columns. Each table is transformed by P = X/sum(X). The average of P is computing. A correspondence analysis is realized on this average. The initial rows and the initial columns are projected in supplementary elements.

Usage

foucart(X, scannf = TRUE, nf = 2) "plot"(x, xax = 1, yax = 2, clab = 1, csub = 2, possub = "bottomright", ...) "print"(x, ...)

Arguments

X
a list of data frame where the row names and the column names are the same for each table
scannf
a logical value indicating whether the eigenvalues bar plot should be displayed
nf
if scannf FALSE, an integer indicating the number of kept axes
x
an object of class 'foucart'
xax
the column number of the x-axis
yax
the column number of the y-axis
clab
if not NULL, a character size for the labels, used with par("cex")*clab
csub
a character size for the legend, used with par("cex")*csub
possub
a string of characters indicating the sub-title position ("topleft", "topright", "bottomleft", "bottomright")
...
further arguments passed to or from other methods

Value

foucart returns a list of the classes 'dudi', 'coa' and 'foucart'
call
origine
nf
axes-components saved
rank
rank
blo
useful vector
cw
vector: column weights
lw
vector: row weights
eig
vector: eigen values
tab
data.frame: modified array
li
data.frame: row coordinates
l1
data.frame: row normed scores
co
data.frame: column coordinates
c1
data.frame: column normed scores
Tli
data.frame: row coordinates (each table)
Tco
data.frame: col coordinates (each table)
TL
data.frame: factors for Tli
TC
data.frame: factors for Tco

References

Foucart, T. (1984) Analyse factorielle de tableaux multiples, Masson, Paris.

Examples

Run this code
data(bf88)
fou1 <- foucart(bf88, scann = FALSE, nf = 3)
fou1
plot(fou1)

data(meaudret)
l1 <- split(meaudret$spe, meaudret$design$season)
l1 <- lapply(l1, function(x) 
    {row.names(x) <- paste("Sit",1:5,sep="");x})
fou2 <- foucart(l1, scan = FALSE)

if(adegraphicsLoaded()) {
  kplot(fou2, row.plabels.cex = 2)
} else {
  kplot(fou2, clab.r = 2)
}

Run the code above in your browser using DataLab