Learn R Programming

ade4 (version 1.7-4)

mbpcaiv: Multiblock principal component analysis with instrumental variables

Description

Function to perform a multiblock redundancy analysis of several explanatory blocks $(X_1, \dots, X_k)$, defined as an object of class ktab, to explain a dependent dataset $Y$, defined as an object of class dudi

Usage

mbpcaiv(dudiY, ktabX, scale = TRUE, option = c("uniform", "none"), scannf = TRUE, nf = 2)

Arguments

dudiY
an object of class dudi containing the dependent variables
ktabX
an object of class ktab containing the blocks of explanatory variables
scale
logical value indicating whether the explanatory variables should be standardized
option
an option for the block weighting. If uniform, the block weight is equal to $1/K$ for $(X_1, \dots, X_K)$ and to $1$ for $X$ and $Y$. If none, the block weight is equal to the block inertia
scannf
logical value indicating whether the eigenvalues bar plot should be displayed
nf
integer indicating the number of kept dimensions

Value

call
the matching call
tabY
data frame of dependent variables centered, eventually scaled (if scale=TRUE) and weighted (if option="uniform")
tabX
data frame of explanatory variables centered, eventually scaled (if scale=TRUE) and weighted (if option="uniform")
TL, TC
data frame useful to manage graphical outputs
nf
numeric value indicating the number of kept dimensions
lw
numeric vector of row weights
X.cw
numeric vector of column weighs for the explanalatory dataset
blo
vector of the numbers of variables in each explanatory dataset
rank
maximum rank of the analysis
eig
numeric vector containing the eigenvalues
lX
matrix of the global components associated with the whole explanatory dataset (scores of the individuals)
lY
matrix of the components associated with the dependent dataset
Yc1
matrix of the variable loadings associated with the dependent dataset
Tli
matrix containing the partial components associated with each explanatory dataset
Tl1
matrix containing the normalized partial components associated with each explanatory dataset
Tfa
matrix containing the partial loadings associated with each explanatory dataset
cov2
squared covariance between lY and Tl1
Yco
matrix of the regression coefficients of the dependent dataset onto the global components
faX
matrix of the regression coefficients of the whole explanatory dataset onto the global components
XYcoef
list of matrices of the regression coefficients of the whole explanatory dataset onto the dependent dataset
bip
block importances for a given dimension
bipc
cumulated block importances for a given number of dimensions
vip
variable importances for a given dimension
vipc
cumulated variable importances for a given number of dimensions

References

Bougeard, S., Qannari, E.M. and Rose, N. (2011) Multiblock Redundancy Analysis: interpretation tools and application in epidemiology. Journal of Chemometrics, 23, 1-9

See Also

mbpls, testdim.multiblock, randboot.multiblock

Examples

Run this code
data(chickenk)
Mortality <- chickenk[[1]]
dudiY.chick <- dudi.pca(Mortality, center = TRUE, scale = TRUE, scannf =
FALSE)
ktabX.chick <- ktab.list.df(chickenk[2:5])
resmbpcaiv.chick <- mbpcaiv(dudiY.chick, ktabX.chick, scale = TRUE,
option = "uniform", scannf = FALSE)
summary(resmbpcaiv.chick)
if(adegraphicsLoaded())
plot(resmbpcaiv.chick)

Run the code above in your browser using DataLab