Learn R Programming

ade4 (version 1.7-24)

s.arrow: Plot of the factorial maps for the projection of a vector basis

Description

performs the scatter diagrams of the projection of a vector basis.

Usage

s.arrow(dfxy, xax = 1, yax = 2, label = row.names(dfxy), 
    clabel = 1, pch = 20, cpoint = 0, boxes = TRUE, edge = TRUE, origin = c(0,0), 
    xlim = NULL, ylim = NULL, grid = TRUE, addaxes = TRUE, cgrid = 1, 
    sub = "", csub = 1.25, possub = "bottomleft", pixmap = NULL, 
    contour = NULL, area = NULL, add.plot = FALSE)

Arguments

Value

The matched call.

Examples

Run this code
s.arrow(cbind.data.frame(runif(55,-2,3), runif(55,-3,2)))

Run the code above in your browser using DataLab