Learn R Programming

ade4 (version 1.7-24)

sco.match: 1D plot of a pair of numeric scores with labels

Description

Draws evenly spaced labels, each label linked to the corresponding values of two numeric score.

Usage

sco.match(score1, score2, label = names(score1), clabel = 1, 
    horizontal = TRUE, reverse = FALSE, pos.lab = 0.5, wmatch = 3, 
    pch = 20, cpoint = 1, boxes = TRUE, lim = NULL, grid = TRUE, 
    cgrid = 1, include.origin = TRUE, origin = c(0, 0), sub = "", 
    csub = 1.25, possub = "bottomleft")

Arguments

Value

The matched call.

Examples

Run this code
sco.match(-5:5,2*(-5:5))

Run the code above in your browser using DataLab