It includes double redundancy analysis (RDA, if dudi argument is created with
dudi.pca) and double canonical correspondence analysis (CCA, if dudi
argument is created with dudi.coa) as special cases. The function dvaripart
computed associated double (by row and column) variation partitioning.
dpcaiv(dudi, dfR = NULL, dfQ = NULL, scannf = TRUE, nf = 2)
# S3 method for dpcaiv
plot(x, xax = 1, yax = 2, ...)
# S3 method for dpcaiv
print(x, ...)
# S3 method for dpcaiv
summary(object, ...)
# S3 method for dpcaiv
randtest(xtest, nrepet = 99, ...)
dvaripart(Y, dfR, dfQ, nrepet = 999, scale = FALSE, ...)
# S3 method for dvaripart
print(x, ...)returns an object of class dpcaiv, sub-class of class dudi
a data frame with the modified array (predicted table)
a numeric vector with the column weigths (from dudi)
a numeric vector with the row weigths (from dudi)
a vector with the all eigenvalues
an integer indicating the rank of the studied matrix
an integer indicating the number of kept axes
a data frame with the Constrained Principal Axes (CPA)
a data frame with the loadings for Q to build the CPA as a linear combination
a data frame with the constrained (by R) row score (LC score)
a data frame with the unconstrained row score (WA score)
data frame with the Constrained Principal Components (CPC)
a data frame with the loadings for R to build the CPC as a linear combination
a data frame with the constrained (by Q) column score (LC score)
a data frame with the unconstrained column score (WA score)
the matched call
a data frame with the dependant variables
a data frame with the explanatory variables for rows
a data frame with the explanatory variables for columns
a data frame with the Principal axes of dudi$tab on CPA
a data frame with the Principal components of dudi$tab on CPC
a data frame with the correlations between the CPC and R
a data frame with the correlations between the CPA and Q
a duality diagram, object of class dudi
a duality diagram, object of class dudi or a response data.frame
a data frame with external variables relative to rows of the
dudi object
a data frame with external variables relative to columns of the
dudi object
a logical value indicating whether the eigenvalues bar plot should be displayed
if scannf FALSE, an integer indicating the number of kept axes
an object of class dpcaiv or dvaripart
the column number for the x-axis
the column number for the y-axis
an integer indicating the number of permutations
If Y is not a dudi, a logical indicating if
variables should be scaled
further arguments passed to or from other methods
Stéphane Dray stephane.dray@univ-lyon1.fr
Lisa Nicvert
Rao, C. R. (1964) The use and interpretation of principal component analysis in applied research. Sankhya, A 26, 329--359.
Obadia, J. (1978) L'analyse en composantes explicatives. Revue de Statistique Appliquee, 24, 5--28.
Lebreton, J. D., Sabatier, R., Banco G. and Bacou A. M. (1991)
Principal component and correspondence analyses with respect to instrumental variables :
an overview of their role in studies of structure-activity and species- environment relationships.
In J. Devillers and W. Karcher, editors. Applied Multivariate Analysis in SAR and Environmental Studies,
Kluwer Academic Publishers, 85--114.
Ter Braak, C. J. F. (1986) Canonical correspondence analysis : a new eigenvector technique for multivariate direct gradient analysis. Ecology, 67, 1167--1179.
Ter Braak, C. J. F. (1987) The analysis of vegetation-environment relationships by canonical correspondence analysis. Vegetatio, 69, 69--77.
Chessel, D., Lebreton J. D. and Yoccoz N. (1987) Propriétés de l'analyse canonique des correspondances. Une utilisation en hydrobiologie. Revue de Statistique Appliquée, 35, 55--72.
# example of a double canonical correspondence analysis
data(aviurba)
coa <- dudi.coa(aviurba$fau, scannf = FALSE)
dcca <- dpcaiv(coa, aviurba$mil, aviurba$trait, scannf = FALSE)
dcca
summary(dcca)
plot(dcca)
randtest(dcca)
dvaripart(coa, aviurba$mil, aviurba$trait, nrepet = 99)
Run the code above in your browser using DataLab