an integer indicating the number of kept axes for each separated analysis
x, object
an object of class 'sepan'
mfrow
a vector of the form "c(nr,nc)", otherwise computed by a special own function n2mfrow
csub
a character size for the sub-titles, used with par("cex")*csub
...
further arguments passed to or from other methods
Value
returns a list of class 'sepan' containing :
call
a call order
tab.names
a vector of characters with the names of tables
blo
a numeric vector with the numbers of columns for each table
rank
a numeric vector with the rank of the studied matrix for each table
Eig
a numeric vector with all the eigenvalues
Li
a data frame with the row coordinates
L1
a data frame with the row normed scores
Co
a data frame with the column coordinates
C1
a data frame with the column normed coordinates
TL
a data frame with the factors for Li L1
TC
a data frame with the factors for Co C1
Details
The function plot on a sepan object allows to compare inertias and structures between arrays.
In black, the eigenvalues of kept axes in the object 'sepan'.