Learn R Programming

ade4 (version 1.7-4)

statis: STATIS, a method for analysing K-tables

Description

performs a STATIS analysis of a ktab object.

Usage

statis(X, scannf = TRUE, nf = 3, tol = 1e-07) "plot"(x, xax = 1, yax = 2, option = 1:4, ...) "print"(x, ...)

Arguments

X
an object of class 'ktab'
scannf
a logical value indicating whether the number of kept axes for the compromise should be asked
nf
if scannf FALSE, an integer indicating the number of kept axes for the compromise
tol
a tolerance threshold to test whether the distance matrix is Euclidean : an eigenvalue is considered positive if it is larger than -tol*lambda1 where lambda1 is the largest eigenvalue
x
an object of class 'statis'
xax, yax
the numbers of the x-axis and the y-axis
option
an integer between 1 and 4, otherwise the 4 components of the plot are dispayed
...
further arguments passed to or from other methods

Value

statis returns a list of class 'statis' containing :
RV
a matrix with the all RV coefficients
RV.eig
a numeric vector with all the eigenvalues
RV.coo
a data frame with the array scores
tab.names
a vector of characters with the names of the arrays
RV.tabw
a numeric vector with the array weigths
C.nf
an integer indicating the number of kept axes
C.rank
an integer indicating the rank of the analysis
C.li
a data frame with the row coordinates
C.Co
a data frame with the column coordinates
C.T4
a data frame with the principal vectors (for each table)
TL
a data frame with the factors (not used)
TC
a data frame with the factors for Co
T4
a data frame with the factors for T4

References

Lavit, C. (1988) Analyse conjointe de tableaux quantitatifs, Masson, Paris. Lavit, C., Escoufier, Y., Sabatier, R. and Traissac, P. (1994) The ACT (Statis method). Computational Statistics and Data Analysis, 18, 97--119.

Examples

Run this code
data(jv73)
kta1 <- ktab.within(withinpca(jv73$morpho, jv73$fac.riv, scann = FALSE))
statis1 <- statis(kta1, scann = FALSE)
plot(statis1)

dudi1 <- dudi.pca(jv73$poi, scann = FALSE, scal = FALSE)
wit1 <- wca(dudi1, jv73$fac.riv, scann = FALSE)
kta3 <- ktab.within(wit1)
data(jv73)
statis3 <- statis(kta3, scann = FALSE)
plot(statis3)

if(adegraphicsLoaded()) {
  s.arrow(statis3$C.li, pgrid.text.cex = 0)
  kplot(statis3, traj = TRUE, arrow = FALSE, plab.cex = 0, psub.cex = 3, ppoi.cex = 3)
} else {
  s.arrow(statis3$C.li, cgrid = 0)
  kplot(statis3, traj = TRUE, arrow = FALSE, unique = TRUE, 
    clab = 0, csub = 3, cpoi = 3)
}

statis3

Run the code above in your browser using DataLab