Learn R Programming

ade4 (version 1.7-4)

tintoodiel: Tinto and Odiel estuary geochemistry

Description

This data set contains informations about geochemical characteristics of heavy metal pollution in surface sediments of the Tinto and Odiel river estuary (south-western Spain).

Usage

data(tintoodiel)

Arguments

Format

tintoodiel is a list containing the following objects :
xy
: a data frame that contains spatial coordinates of the 52 sites
tab
: a data frame with 12 columns (concentration of heavy metals) and 52 rows (sites)
neig
: an object of class neig

Borrego, J., Morales, J.A., de la Torre, M.L. and Grande, J.A. (2002) Geochemical characteristics of heavy metal pollution in surface sediments of the Tinto and Odiel river estuary (south-western Spain). Environmental Geology, 41, 785--796.

Examples

Run this code
data(tintoodiel)
if(!adegraphicsLoaded()) {
  ## Not run: 
#   if(requireNamespace("pixmap", quiet = TRUE)) {
#     estuary.pnm <- read.pnm(system.file("pictures/tintoodiel.pnm", package = "ade4"))
#     s.label(tintoodiel$xy, pixmap = estuary.pnm, neig = tintoodiel$neig,
#       clab = 0, cpoi = 2, cneig = 3, addax = FALSE, cgrid = 0, grid = FALSE)
#   }## End(Not run)
  
  estuary.pca <- dudi.pca(tintoodiel$tab, scan = FALSE, nf = 4)
  
  if(requireNamespace("maptools", quiet = TRUE) & requireNamespace("spdep", quiet = TRUE)) {
    estuary.listw <- nb2listw(neig2nb(tintoodiel$neig))
    estuary.pca.ms <- multispati(estuary.pca, estuary.listw, scan = FALSE, nfposi = 3, nfnega = 2)
    summary(estuary.pca.ms)
    par(mfrow = c(1, 2))
    barplot(estuary.pca$eig)
    barplot(estuary.pca.ms$eig)
    par(mfrow = c(1, 1))
}}

Run the code above in your browser using DataLab